/* star-merge.h:
 *
 ****************************************************************
 * Copyright (C) 2003 Tom Lord
 *
 * See the file "COPYING" for further information about
 * the copyright and warranty status of this work.
 */

#ifndef INCLUDE__LIBARCH__STAR_MERGE_H
#define INCLUDE__LIBARCH__STAR_MERGE_H


#include "hackerlab/machine/types.h"
#include "libarch/archive.h"


extern int arch_star_merge (int chatter_fd,
                            struct arch_archive * from_arch, t_uchar * from_archive, t_uchar * from_revision,
                            arch_project_tree_t * to_tree, struct arch_archive * to_arch, t_uchar * to_archive, t_uchar * to_version,
                            arch_project_tree_t * cache, t_uchar * changeset_output, int use_diff3, int forward,
                            int escape_classes, int show_points_only, int graph_merge, int trace);
#endif  /* INCLUDE__LIBARCH__STAR_MERGE_H */


/* tag: Tom Lord Sat Jan  5 15:26:10 2002 (star-merge.h)
 */
